@@ -64,7 +64,7 @@ class VideoBaseModel(SRModel):
                 else:
                     if 'vimeo' in dataset_name.lower():  # vimeo90k dataset
                         split_result = lq_path.split('/')
-                        img_name = (f'{split_result[-3]}_{split_result[-2]}_' f'{split_result[-1].split(".")[0]}')
+                        img_name = f'{split_result[-3]}_{split_result[-2]}_{split_result[-1].split(".")[0]}'
                     else:  # other datasets, e.g., REDS, Vid4
                         img_name = osp.splitext(osp.basename(lq_path))[0]
 
@@ -87,7 +87,7 @@ class VideoBaseModel(SRModel):
             if rank == 0:
                 for _ in range(world_size):
                     pbar.update(1)
-                    pbar.set_description(f'Test {folder}:' f'{int(frame_idx) + world_size}/{max_idx}')
+                    pbar.set_description(f'Test {folder}: {int(frame_idx) + world_size}/{max_idx}')
         if rank == 0:
             pbar.close()
 
